package wicket.exemplo;

import java.util.Arrays;

import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.form.ChoiceRenderer;
import org.apache.wicket.markup.html.form.DropDownChoice;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.html.panel.FeedbackPanel;
import org.apache.wicket.model.CompoundPropertyModel;

/*
 * Este exemplo introduz o CompoundPropertyModel.
 * 
 * O parmetro do construtor pode receber um IModel tambm. Ex:
 * new CompoundPropertyModel(new PropertyModel(this, "pessoa"))
 * 
 * Isso permite uma grande flexibilidade. Veja que usando como est no exemplo abaixo 
 * (passando pessoa diretamente no construtor), usa sempre a mesma instncia, a que
 * foi criada no incio. Se o atributo pessoa de HomePage for alterado, isso no ir
 * refletir na pgina. Nestes casos, usar PropertyModel  mais interessante.  
 */
public class HomePage extends WebPage {

	private Pessoa pessoa = new Pessoa();

	public HomePage() {

		FeedbackPanel feedbackPanel = new FeedbackPanel("feedback");
		add(feedbackPanel);

		Form form = new Form("form", new CompoundPropertyModel(pessoa)) {
			@Override
			protected void onSubmit() {
				HomePage.this.onFormSubmit();
			}
		};
		add(form);

		TextField nome = new TextField("nome");
		form.add(nome);

		ChoiceRenderer renderer = new ChoiceRenderer("nome");
		DropDownChoice sexo = new DropDownChoice("sexo", Arrays.asList(Sexo
				.values()), renderer);
		form.add(sexo);

		TextField idade = new TextField("idade");
		form.add(idade);

		TextField endereco = new TextField("endereco");
		form.add(endereco);
	}

	protected void onFormSubmit() {
		System.out.println("Pessoa: " + pessoa);
	}

}
