package wicket.exemplo;

import java.math.BigDecimal;
import java.util.Arrays;
import java.util.Date;
import java.util.Locale;

import org.apache.wicket.Session;
import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.form.DropDownChoice;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.html.panel.FeedbackPanel;
import org.apache.wicket.model.IModel;
import org.apache.wicket.model.PropertyModel;

/**
 * Este exemplo mostra como os converters levam em considerao o locale. Note
 * que a primeira vez que executar o exemplo, o locale selecionado ser o
 * configurado no seu browser. Veja abaixo que no h cdigo algum para isso: 
 * automtico.
 * 
 * Experimente fechar alterar a configurao de idioma do browser, reinici-lo e
 * abrir o exemplo novamente.
 * 
 * O exemplo mostra tambm como criar um IModel que acesse diretamente o Locale
 * da sesso.
 */
public class HomePage extends WebPage {

    /**
     * Locales disponveis na lista.
     */
	private static final Locale[] LOCALES = { new Locale("pt", "BR"),
            Locale.US, Locale.JAPAN };

    private Date data = new Date();

    private BigDecimal bigDecimal = new BigDecimal("123.456");

	public HomePage() {

		FeedbackPanel feedbackPanel = new FeedbackPanel("feedback");
		add(feedbackPanel);

		final Form form = new Form("form");
		add(form);
		
		IModel localeModel = new IModel() {
            public Object getObject() {
                return Session.get().getLocale();
            }

            public void setObject(Object object) {
                Session.get().setLocale((Locale) object);

            }

            public void detach() {
            }
        };

        DropDownChoice locales = new DropDownChoice("locale", localeModel,
                Arrays
                .asList(LOCALES));
        form.add(locales);

        TextField data = new TextField("data", new PropertyModel(this, "data"));
        form.add(data);

		TextField bigDecimal = new TextField("bigDecimal", new PropertyModel(
                this, "bigDecimal"));
        form.add(bigDecimal);
		
	}

    public Date getData() {
        return data;
    }

    public void setData(Date data) {
        this.data = data;
    }

    public BigDecimal getBigDecimal() {
        return bigDecimal;
    }

    public void setBigDecimal(BigDecimal bigDecimal) {
        this.bigDecimal = bigDecimal;
    }

}
