package wicket.exemplo;

import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.Date;
import java.util.Locale;

import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.html.panel.FeedbackPanel;
import org.apache.wicket.model.PropertyModel;
import org.apache.wicket.util.convert.IConverter;
import org.apache.wicket.util.convert.converters.BigDecimalConverter;

/**
 * Exemplo de como mudar converters.
 * 
 * Muda o converter padro para um determinado tipo (veja em
 * {@link HelloApplication#newConverterLocator()}) e muda o converter para um
 * campo especfico.
 * 
 * Outra mudana  que foi criado o componente LocaleDropDown, que servia no
 * exemplo anterior para mudar o Locale do usurio. Note como  fcil criar
 * componentes.
 */
public class HomePage extends WebPage {

    private Date data = new Date();

    private BigDecimal bigDecimal = new BigDecimal("123.456");

	public HomePage() {

		FeedbackPanel feedbackPanel = new FeedbackPanel("feedback");
		add(feedbackPanel);

		final Form form = new Form("form");
		add(form);
		
		LocaleDropDown locales = new LocaleDropDown("locale");
        form.add(locales);

        TextField data = new TextField("data", new PropertyModel(this, "data"));
        form.add(data);

        /*
         * Sobrescrevendo o converter do TextField
         */
		TextField bigDecimal = new TextField("bigDecimal", new PropertyModel(
                this, "bigDecimal")) {
		    
            @SuppressWarnings("unchecked")
            @Override
            public IConverter getConverter(Class type) {
                return new BrasilDecimalConverter();
            }
            
        };
        form.add(bigDecimal);
		
	}

    /**
     * Outro converter para BigDecimal.
     */
	public static class BrasilDecimalConverter extends BigDecimalConverter {

	    @Override
        public NumberFormat getNumberFormat(Locale locale) {
            return new DecimalFormat("0.00");
        }

    }

    public Date getData() {
        return data;
    }

    public void setData(Date data) {
        this.data = data;
    }

    public BigDecimal getBigDecimal() {
        return bigDecimal;
    }

    public void setBigDecimal(BigDecimal bigDecimal) {
        this.bigDecimal = bigDecimal;
    }

}
