package wicket.exemplo;

import java.util.Map;
import java.util.regex.Pattern;

import org.apache.wicket.util.parse.metapattern.MetaPattern;
import org.apache.wicket.validation.IValidatable;
import org.apache.wicket.validation.validator.PatternValidator;

/**
 * Exemplo de um PatternValidator que possibilita mostrar um padro mais
 * amigvel no aviso. Ex:
 * <p>
 * A mensagem ser gerada com a chave "PatternAmigavelValidator" e os parmetros
 * so os mesmos de {@link PatternValidator} alm de:
 * <p>
 * <ul>
 * <li>${padraoAmigavel}: o texto usado como parmetro no construtor.</li>
 * </ul>
 */
public class PatternAmigavelValidator extends PatternValidator {
    
    private String padraoAmigavel;

    public PatternAmigavelValidator(MetaPattern pattern, String padraoAmigavel) {
        super(pattern);
        this.padraoAmigavel = padraoAmigavel;
    }

    public PatternAmigavelValidator(Pattern pattern, String padraoAmigavel) {
        super(pattern);
        this.padraoAmigavel = padraoAmigavel;
    }

    public PatternAmigavelValidator(String pattern, int flags,
            String padraoAmigavel) {
        super(pattern, flags);
        this.padraoAmigavel = padraoAmigavel;
    }

    public PatternAmigavelValidator(String pattern, String padraoAmigavel) {
        super(pattern);
        this.padraoAmigavel = padraoAmigavel;
    }
    
    @SuppressWarnings("unchecked")
    @Override
    protected Map variablesMap(IValidatable validatable) {
        Map map = super.variablesMap(validatable);
        map.put("padraoAmigavel", padraoAmigavel);
        return map;
    }

}
