package wicket.exemplo;

import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.html.list.ListItem;
import org.apache.wicket.markup.html.list.ListView;
import org.apache.wicket.model.LoadableDetachableModel;
import org.apache.wicket.model.Model;
import org.apache.wicket.model.PropertyModel;

import wicket.bugtracker.negocio.BugTracker;
import wicket.bugtracker.negocio.Projeto;
import wicket.bugtracker.negocio.ProjetoDao;

/**
 * Exemplo de uma consulta com LoadableDetachableModel.
 */
public class HomePage extends WebPage {
    
    private String busca;
    
    public HomePage() {
        
        Form form = new Form("formBusca");
        add(form);
        
        TextField campoBusca = new TextField("campoBusca", new PropertyModel(
                this, "busca"));
        form.add(campoBusca);

        ListView projetos = new ListView("projetos", new ProjetosModel()) {

            @Override
            protected void populateItem(ListItem item) {
                Projeto projeto = (Projeto) item.getModelObject();
                item.add(new Label("id", new Model(projeto.getId())));
                item.add(new Label("nome", new Model(projeto.getNome())));
                Model bugsModel = new Model(projeto.getBugs().size());
                item.add(new Label("bugs", bugsModel));
            }

        };
        add(projetos);
    }
    
    public class ProjetosModel extends LoadableDetachableModel {

        @Override
        protected Object load() {
            BugTracker bugTracker = HelloApplication.get().getBugTracker();
            ProjetoDao dao = bugTracker.getProjetoDao();
            return dao.findPorNome(busca);
        }

    }

    public String getBusca() {
        return busca;
    }

    public void setBusca(String busca) {
        this.busca = busca;
    }

}
