package wicket.exemplo;

import org.apache.commons.lang.StringUtils;
import org.apache.wicket.ajax.AjaxRequestTarget;
import org.apache.wicket.extensions.ajax.markup.html.IndicatingAjaxButton;
import org.apache.wicket.markup.html.WebMarkupContainer;
import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.html.list.ListItem;
import org.apache.wicket.markup.html.list.ListView;
import org.apache.wicket.model.LoadableDetachableModel;
import org.apache.wicket.model.Model;
import org.apache.wicket.model.PropertyModel;

import wicket.bugtracker.negocio.BugTracker;
import wicket.bugtracker.negocio.Projeto;
import wicket.bugtracker.negocio.ProjetoDao;

/**
 * Um extra... O mesmo formulrio do exemplo anterior mas com Ajax! Foram
 * necessrias algumas pequenas modificaes:
 * <ul>
 * <li>Boto do formulrio virou um compontente: teve que ter wicket:id e o
 * componente do lado de c IndicatingAjaxButton.</li>
 * <li>Um novo container por fora dos elementos da tabela: a tabela virou tambm
 * um componente, mas um simples WebMarkupContainer. O Ajax funciona dizendo ao
 * Wicket quais componentes queremos renderizar aps uma requisio. E isso no
 *  permitido com componentes repetidores diretamente.</li>
 * <li>Este componente precisa ter o setOutputMarkupId ligado. Usei tambm o
 * setMarkupId mas porque quero usar um id especfico.</li>
 * <li>Simulei um tempo de espera para poder ver o indicador de tempo no
 * cliente.</li>
 * </ul>
 * 
 */
public class HomePage extends WebPage {
    
    private String busca;
    
    private WebMarkupContainer tabelaProjetos;
    
    public HomePage() {
        
        Form form = new Form("formBusca");
        add(form);
        
        TextField campoBusca = new TextField("campoBusca", new PropertyModel(
                this, "busca"));
        form.add(campoBusca);
        
        IndicatingAjaxButton botao = new IndicatingAjaxButton("botao", form) {
            @Override
            protected void onSubmit(AjaxRequestTarget target, Form form) {
                esperar(1500);
                target.addComponent(tabelaProjetos);
            }
        };
        form.add(botao);

        tabelaProjetos = new WebMarkupContainer("tabelaProjetos");
        tabelaProjetos.setMarkupId("tabelaProjetos");
        tabelaProjetos.setOutputMarkupId(true);
        add(tabelaProjetos);
        
        ListView projetos = new ListView("projetos", new ProjetosModel()) {

            @Override
            protected void populateItem(ListItem item) {
                Projeto projeto = (Projeto) item.getModelObject();
                item.add(new Label("id", new Model(projeto.getId())));
                item.add(new Label("nome", new Model(projeto.getNome())));
                Model bugsModel = new Model(projeto.getBugs().size());
                item.add(new Label("bugs", bugsModel));
            }

        };
        tabelaProjetos.add(projetos);
    }
    
    public class ProjetosModel extends LoadableDetachableModel {

        @Override
        protected Object load() {
            BugTracker bugTracker = HelloApplication.get().getBugTracker();
            ProjetoDao dao = bugTracker.getProjetoDao();
            if (StringUtils.isBlank(busca)) {
                return dao.lista();
            } else {
                return dao.findPorNome(busca);
            }
        }

    }
    
    public void esperar(long milissegundos) {
        try {
            Thread.sleep(milissegundos);
        } catch (InterruptedException e) {
            // Ignorar
            e.printStackTrace();
        }
    }

    public String getBusca() {
        return busca;
    }

    public void setBusca(String busca) {
        this.busca = busca;
    }

}
