package wicket.exemplo;

import java.util.Iterator;

import org.apache.wicket.extensions.markup.html.repeater.util.SortableDataProvider;
import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.repeater.Item;
import org.apache.wicket.markup.repeater.data.DataView;
import org.apache.wicket.markup.repeater.data.IDataProvider;
import org.apache.wicket.model.IModel;
import org.apache.wicket.model.LoadableDetachableModel;
import org.apache.wicket.model.Model;
import org.apache.wicket.model.PropertyModel;

import wicket.bugtracker.negocio.BugTracker;
import wicket.bugtracker.negocio.Projeto;
import wicket.bugtracker.negocio.ProjetoDao;

public class HomePage extends WebPage {
    
    private String busca;
    
    public HomePage() {
        
        Form form = new Form("formBusca");
        add(form);
        
        TextField campoBusca = new TextField("campoBusca", new PropertyModel(
                this, "busca"));
        form.add(campoBusca);
        
        DataView projetos = new ProjetosDataView("projetos",
                new ProjetosDataProvider());
        add(projetos);
    }

    /**
     * DataView para a lista de projetos.
     */
    private final class ProjetosDataView extends DataView {

        private ProjetosDataView(String id, IDataProvider dataProvider) {
            super(id, dataProvider);
        }

        @Override
        protected void populateItem(Item item) {
            Projeto projeto = (Projeto) item.getModelObject();
            item.add(new Label("id", new Model(projeto.getId())));
            item.add(new Label("nome", new Model(projeto.getNome())));
            Model bugsModel = new Model(projeto.getBugs().size());
            item.add(new Label("bugs", bugsModel));
        }
    }

    /**
     * Data provider para a lista de projetos.
     */
    protected class ProjetosDataProvider extends SortableDataProvider {
        
        protected ProjetoDao getDao() {
            BugTracker bugTracker = HelloApplication.get().getBugTracker();
            return bugTracker.getProjetoDao();
        }

        public Iterator<Projeto> iterator(int first, int count) {
            return getDao().findPorNome(busca, first, count).iterator();
        }

        public IModel model(Object object) {
            return new ProjetoDetachableModel(((Projeto) object).getId());
        }

        public int size() {
            return getDao().countPorNome(busca);
        }
        
    }

    /**
     * {@link LoadableDetachableModel} para um projeto.
     */
    protected static class ProjetoDetachableModel extends
            LoadableDetachableModel {

        private int id;

        public ProjetoDetachableModel(int id) {
            this.id = id;
        }

        @Override
        protected Object load() {
            BugTracker bugTracker = HelloApplication.get().getBugTracker();
            return bugTracker.getProjetoDao().get(id);
        }

    }
    
    public String getBusca() {
        return busca;
    }

    public void setBusca(String busca) {
        this.busca = busca;
    }

}
