package wicket.exemplo;

import org.apache.wicket.PageParameters;
import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.model.Model;

import wicket.bugtracker.negocio.BugTracker;
import wicket.bugtracker.negocio.Projeto;
import wicket.bugtracker.negocio.ProjetoDao;

/**
 * Pgina que pode ser acessada tanto por cdigo quanto por URL
 */
public class DetalhesProjeto extends WebPage {
	
	private Projeto projeto;

	/**
	 * Construtor para receber parmetros da URL
	 */
	public DetalhesProjeto(PageParameters parameters) {
		BugTracker bugTracker = HelloApplication.get().getBugTracker();
		ProjetoDao dao = bugTracker.getProjetoDao();
		int id = parameters.getInt("id", 0);
		if (id == 0) {
			throw new RuntimeException("Projeto inexistente");
		}
		projeto = dao.get(id);
		if (projeto == null) {
			throw new RuntimeException("Projeto " + id + " inexistente");
		}
		construirPagina();
	}
	
	/**
	 * Construtor para ser usado dentro do sistema
	 */
    public DetalhesProjeto(Projeto projeto) {
		this.projeto = projeto;
		construirPagina();
	}

	private void construirPagina() {
		add(new Label("id", new Model(projeto.getId())));
		add(new Label("nome", projeto.getNome()));
		add(new Label("bugs", new Model(projeto.getBugs().size())));

		Link excluir = new Link("linkExcluir") {
			@Override
			public void onClick() {
				System.out.println("Projeto de ID " + projeto.getId()
						+ " foi excludo");
			}
		};
		add(excluir);
    }

}
