package wicket.exemplo;

import org.apache.wicket.PageParameters;
import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.model.AbstractReadOnlyModel;
import org.apache.wicket.model.PropertyModel;

/**
 * Pgina que pode ser acessada tanto por cdigo quanto por URL.
 * <p>
 * A diferena do outro exemplo  que a pgina guarda um LoadableDetachableModel
 * para a entidade ao invs da entidade diretamente. Isso reduz o uso de memria
 * e melhora a sincronia com o banco de dados.
 * <p>
 * Por outro lado, causa um SELECT no banco sempre que a pgina for renderizada.
 * <p>
 * Ento, h a troca de perder um pouco no desempenho em troca de memria.
 */
public class DetalhesProjeto extends WebPage {
	
	private ProjetoDetachableModel projeto;

	/**
	 * Construtor para receber parmetros da URL
	 */
	public DetalhesProjeto(PageParameters parameters) {
		int id = parameters.getInt("id", 0);
		if (id == 0) {
			throw new RuntimeException("Projeto inexistente");
		}
		projeto = new ProjetoDetachableModel(id);
		construirPagina();
	}
	
	/**
	 * Construtor para ser usado dentro do sistema
	 */
    public DetalhesProjeto(int projetoId) {
        this.projeto = new ProjetoDetachableModel(projetoId);
		construirPagina();
	}

	private void construirPagina() {
		add(new Label("id", new PropertyModel(projeto, "id")));
        add(new Label("nome", new PropertyModel(projeto, "nome")));
        add(new Label("bugs", new AbstractReadOnlyModel() {
            @Override
            public Object getObject() {
                return projeto.getProjeto().getBugs().size();
            }
        }));

		Link excluir = new Link("linkExcluir") {
			@Override
			public void onClick() {
				System.out.println("Projeto de ID " + projeto.getId()
						+ " foi excludo");
			}
		};
		add(excluir);
    }

}
