package wicket.exemplo;

import java.util.Iterator;
import java.util.List;

import org.apache.wicket.PageParameters;
import org.apache.wicket.extensions.markup.html.repeater.util.SortParam;
import org.apache.wicket.extensions.markup.html.repeater.util.SortableDataProvider;
import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.TextField;
import org.apache.wicket.markup.html.link.BookmarkablePageLink;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.markup.html.navigation.paging.PagingNavigator;
import org.apache.wicket.markup.repeater.Item;
import org.apache.wicket.markup.repeater.data.DataView;
import org.apache.wicket.markup.repeater.data.IDataProvider;
import org.apache.wicket.model.IModel;
import org.apache.wicket.model.Model;
import org.apache.wicket.model.PropertyModel;

import wicket.bugtracker.negocio.BugTracker;
import wicket.bugtracker.negocio.Projeto;
import wicket.bugtracker.negocio.ProjetoDao;

public class HomePage extends WebPage {
    
    private String busca;
    
    private ProjetosDataProvider dataProvider;
    
    private DataView projetosView;
    
    public HomePage() {
        
        Form form = new Form("formBusca");
        add(form);
        
        TextField campoBusca = new TextField("campoBusca", new PropertyModel(
                this, "busca"));
        form.add(campoBusca);
        
        dataProvider = new ProjetosDataProvider();
        dataProvider.setSort("nome", true);
        projetosView = new ProjetosDataView("projetos", dataProvider);
        projetosView.setItemsPerPage(5);
        add(projetosView);
        
        PagingNavigator paginacao = new PagingNavigator("paginacao",
                projetosView);
        add(paginacao);
        
        add(new SortLink("headIdLink", "id", dataProvider));
        add(new SortLink("headNomeLink", "nome", dataProvider));
    }

    /**
     * DataView para a lista de projetos.
     */
    private final class ProjetosDataView extends DataView {

        private ProjetosDataView(String id, IDataProvider dataProvider) {
            super(id, dataProvider);
        }

        @Override
        protected void populateItem(final Item item) {
            Projeto projeto = (Projeto) item.getModelObject();
            item.add(new Label("id", new Model(projeto.getId())));
            
            /*
             * Criao de um link do tipo no bookmarkable
             */
             Link linkNaoBookmarkable = new Link("linkNaoBookmarkable") {
                @Override
                public void onClick() {
                    DetalhesProjeto detalhes = new DetalhesProjeto(((ProjetoDetachableModel) item
                            .getModel()).getId());
                    setResponsePage(detalhes);
                }

            };
            item.add(linkNaoBookmarkable);
            
            /*
             * Criao de um link do tipo bookmarkable
             */
            Link linkBookmarkable = new BookmarkablePageLink("linkBookmarkable",
                    DetalhesProjeto.class,
                    new PageParameters("id=" + projeto.getId()));
            item.add(linkBookmarkable);
            
            item.add(new Label("nome", new Model(projeto.getNome())));
            Model bugsModel = new Model(projeto.getBugs().size());
            item.add(new Label("bugs", bugsModel));
        }
    }
    
    protected class SortLink extends Link {

        private String propriedade;
        
        private SortableDataProvider dataProvider;

        public SortLink(String id, String propriedade,
                SortableDataProvider dataProvider) {
            super(id);
            this.propriedade = propriedade;
            this.dataProvider = dataProvider;
        }

        @Override
        public void onClick() {
            HomePage.this.projetosView.setCurrentPage(0);
            SortParam sort = dataProvider.getSort();
            if (sort != null && propriedade.equals(sort.getProperty())) {
                dataProvider.setSort(propriedade, !sort.isAscending());
            } else {
                dataProvider.setSort(propriedade, true);
            }
        }

    }

    /**
     * Data provider para a lista de projetos.
     */
    protected class ProjetosDataProvider extends SortableDataProvider {
        
        protected ProjetoDao getDao() {
            BugTracker bugTracker = HelloApplication.get().getBugTracker();
            return bugTracker.getProjetoDao();
        }

        public Iterator<Projeto> iterator(int first, int count) {
            List<Projeto> projetos = getDao().findPorNomeOrdenado(busca, first, count,
                    getSort().getProperty(), getSort().isAscending());
            return projetos.iterator();
        }

        public IModel model(Object object) {
            return new ProjetoDetachableModel(((Projeto) object).getId());
        }

        public int size() {
            return getDao().countPorNome(busca);
        }
        
    }

    public String getBusca() {
        return busca;
    }

    public void setBusca(String busca) {
        this.busca = busca;
    }

}
