package wicket.bugtracker.negocio;

import java.beans.IntrospectionException;
import java.beans.PropertyDescriptor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public abstract class AbstractDao<T extends Entidade> {
	
	private int ultimoId = 1;
	
	private Map<Integer, T> entidades = new HashMap<Integer, T>();
	
	protected synchronized int novoId() {
		return ultimoId++; 
	}
	
	public void store(T entidade) {
		if (entidade.getId() == null) {
			entidade.setId(novoId());
		}
		entidades.put(entidade.getId(), entidade);
	}

	public void storeAll(Collection<T> entidades) {
		for (T entidade : entidades) {
			store(entidade);
		}
	}
	
	public void delete(T entidade) {
		entidades.remove(entidade.getId());
	}
	
	public T get(int id) {
		return entidades.get(id);
	}
	
	public List<T> lista() {
		return new ArrayList<T>(entidades.values());
	}
	
	public List<T> limitar(List<T> lista, int primeiro, int count) {
		List<T> resultado = new ArrayList<T>();
		for (int i = primeiro; i < Math.min(primeiro + count, lista.size()); i++) {
			resultado.add(lista.get(i));
		}
		return resultado;
	}
	
	public abstract Class<T> getClasseTratada();
	
	public void ordenar(List<T> lista, String propriedade, final boolean ascendente) {
		
		final Method readMethod;
		final PropertyDescriptor descriptor;
		try {
			descriptor = new PropertyDescriptor(propriedade, getClasseTratada());
			readMethod = descriptor.getReadMethod();
		} catch (IntrospectionException e) {
			throw new RuntimeException(e);
		}
		
		Comparator<T> comparator = new Comparator<T>() {

			@SuppressWarnings("unchecked")
			public int compare(T o1, T o2) {
				try {
					Comparable<Object> v1 = (Comparable<Object>) readMethod.invoke(o1);
					Comparable<Object> v2 = (Comparable<Object>) readMethod.invoke(o2);
					int res = v1.compareTo(v2);
					if (ascendente) {
						return res;
					} else {
						return -res;
					}
				} catch (IllegalArgumentException e) {
					throw new RuntimeException(e);
				} catch (IllegalAccessException e) {
					throw new RuntimeException(e);
				} catch (InvocationTargetException e) {
					throw new RuntimeException(e);
				}
			}
			
		};
		
		Collections.sort(lista, comparator);
	}
   
}
