package wicket.bugtracker.negocio;

import java.util.HashSet;
import java.util.Set;

import org.apache.commons.lang.RandomStringUtils;
import org.apache.commons.lang.math.RandomUtils;

public class BugTracker {
	
	private RotuloDao rotuloDao;
	
	private ProjetoDao projetoDao;
	
	private BugDao bugDao;
	
	public BugTracker() {
		rotuloDao = new RotuloDao();
		projetoDao = new ProjetoDao();
		bugDao = new BugDao();
		initDatabase(10, 100, 5, 4);
	}
	
	public BugTracker(int numProjetos, int numBugs, int numRotulos, int maxRotulosPorBug) {
		rotuloDao = new RotuloDao();
		projetoDao = new ProjetoDao();
		bugDao = new BugDao();
		initDatabase(numProjetos, numBugs, numRotulos, maxRotulosPorBug);
	}
	
	protected Set<Rotulo> criarRotulosAleatorios(int count) {
		Set<Rotulo> res = new HashSet<Rotulo>();
		for (int i = 0; i < count; i++) {
			Rotulo rotulo = new Rotulo("Rtulo " + i + " - " + RandomStringUtils.random(20, true, true));
			res.add(rotulo);
			rotuloDao.store(rotulo);
		}
		return res;
	}
	
	protected Set<Projeto> criarProjetosAleatorios(int count) {
		Set<Projeto> projetos = new HashSet<Projeto>();
		for (int i = 0; i < count; i++) {
			Projeto projeto = new Projeto("Projeto " + i + " - " + RandomStringUtils.random(20, true, true));
			projetos.add(projeto);
			projetoDao.store(projeto);
		}
		return projetos;
	}
	
	protected Set<Bug> criarBugsAleatorios(Set<Projeto> projetos, Set<Rotulo> rotulos, int count, int maxRotulos) {
		
		Projeto[] aprojetos = new Projeto[projetos.size()];
		aprojetos = projetos.toArray(aprojetos);
		
		Rotulo[] arotulos = new Rotulo[rotulos.size()];
		arotulos = rotulos.toArray(arotulos);
		
		Set<Bug> bugs = new HashSet<Bug>();
		for (int i = 0; i < count; i++) {
			Bug bug = new Bug();
			Projeto projeto = aprojetos[RandomUtils.nextInt(aprojetos.length)];
			bug.setProjeto(projeto);
			projeto.getBugs().add(bug);
			int rotulosCount = RandomUtils.nextInt(maxRotulos);
			for (int r = 0; r < rotulosCount; r++) {
				Rotulo rotulo = arotulos[RandomUtils.nextInt(arotulos.length)];
				bug.getRotulos().add(rotulo);
			}
			bug.setAssunto("Assunto " + i + " - " + RandomStringUtils.random(40, true, true));
			bug.setDescricao(RandomStringUtils.random(200, true, true));
			bug.setStatus(BugStatus.values()[RandomUtils.nextInt(BugStatus.values().length)]);
			bugs.add(bug);
		}
		return bugs;
	}
	
    protected void initDatabase(int numProjetos, int numBugs, int numRotulos, int maxRotulosPorBug) {
    	Set<Rotulo> rotulos = criarRotulosAleatorios(numRotulos);
    	rotuloDao.storeAll(rotulos);
    	
    	Set<Projeto> projetos = criarProjetosAleatorios(numProjetos);
    	projetoDao.storeAll(projetos);
    	
    	Set<Bug> bugs = criarBugsAleatorios(projetos, rotulos, numBugs, maxRotulosPorBug);
    	bugDao.storeAll(bugs);
	}
    
	public RotuloDao getRotuloDao() {
		return rotuloDao;
	}

	public ProjetoDao getProjetoDao() {
		return projetoDao;
	}

	public BugDao getBugDao() {
		return bugDao;
	}

}
