package wicket.bugtracker.negocio;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;

public class ProjetoDao extends AbstractDao<Projeto> {

    /**
     * Busca projetos que contenham um trecho de string no seu nome. Ignora maisculas e
     * minsculas. Se o parmetro for vazio, retorna todos os projetos.
     */
    public List<Projeto> findPorNome(String nome) {
        if (StringUtils.isBlank(nome)) {
            return lista();
        } else {
            String nomeProcuradoLower = nome.toLowerCase();
            List<Projeto> resultado = new ArrayList<Projeto>();
            List<Projeto> completa = lista();
            for (Projeto projeto : completa) {
                String nomeLower = projeto.getNome().toLowerCase();
                if (nomeLower.contains(nomeProcuradoLower)) {
                    resultado.add(projeto);
                }
            }
            return resultado;
        }
    }

    public List<Projeto> findPorNome(String nome, int primeiro, int count) {
        List<Projeto> projetos = findPorNome(nome);
        return limitar(projetos, primeiro, count);
    }

    public int countPorNome(String nome) {
        return findPorNome(nome).size();
    }

    public List<Projeto> findPorNomeOrdenado(String nome, String propriedade, boolean ascendente) {
        List<Projeto> projetos = findPorNome(nome);
        ordenar(projetos, propriedade, ascendente);
        return projetos;
    }

    public List<Projeto> findPorNomeOrdenado(String nome, int primeiro, int count,
            String propriedade, boolean ascendente) {
        List<Projeto> projetos = findPorNomeOrdenado(nome, propriedade, ascendente);
        return limitar(projetos, primeiro, count);
    }

    @Override
    public Class<Projeto> getClasseTratada() {
        return Projeto.class;
    }

}
